Coverage report

File | function | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src\attipy\__init__.py | (no function) | 2 | 0 | 0 | 0 | 0 | 100%
src\attipy\_attitude.py | AttitudeBase.value | 0 | 0 | 1 | 0 | 0 | 100%
src\attipy\_attitude.py | UnitQuaternion.__init__ | 1 | 0 | 0 | 0 | 0 | 100%
src\attipy\_attitude.py | UnitQuaternion.value | 1 | 0 | 0 | 0 | 0 | 100%
src\attipy\_attitude.py | AttitudeMatrix.__init__ | 3 | 1 | 0 | 2 | 1 | 60%
src\attipy\_attitude.py | AttitudeMatrix.value | 1 | 0 | 0 | 0 | 0 | 100%
src\attipy\_attitude.py | AttitudeMatrix.from_quaternion | 4 | 1 | 0 | 2 | 1 | 67%
src\attipy\_attitude.py | (no function) | 19 | 0 | 0 | 0 | 0 | 100%
src\attipy\_transforms.py | _rot_matrix_from_quaternion | 24 | 24 | 0 | 0 | 0 | 0%
src\attipy\_transforms.py | (no function) | 5 | 0 | 0 | 0 | 0 | 100%
src\attipy\_vectorops.py | _normalize | 1 | 1 | 0 | 0 | 0 | 0%
src\attipy\_vectorops.py | (no function) | 5 | 0 | 0 | 0 | 0 | 100%
Total |  | 66 | 27 | 1 | 4 | 2 | 59%

No items found using the specified filter.